#!/bin/bash
QUALITY=85
THUMB_QUALITY_PNG=70
THUMB_QUALITY_JPG=50

cd $(dirname $(realpath -s ${0}))

function generate_rule() {
  image=${1}
  resolutions=${2}
  default_resolution=${3}
  quality=${4}
  thumb_quality=${5}
  thumb_format=${6}

  for resolution in ${resolutions}; do
    echo "${image}@${resolution}.png: ${image}.png"
    echo "	./generate_resolution ${image} ${resolution} ${quality}"
  done

  case ${thumb_format} in
  "png")
    echo "${image}@thumb.png: ${image}.png"
    echo "	./generate_thumb ${image} ${default_resolution} ${thumb_quality} png"
    ;;
  "jpg")
    echo "${image}@thumb.jpg: ${image}.png"
    echo "	./generate_thumb ${image} ${default_resolution} ${thumb_quality} jpg"
    ;;
  "none")
    echo "${image}@thumb.png: ${image}.png"
    echo "	./generate_thumb ${image} ${default_resolution} ${thumb_quality} none"
    ;;
  *)
    echo "Unknown format: $thumb_format"
    exit 1
    ;;
  esac
}

echo -n > Makefile
# Generate Images
themes="quassel_light quassel_dark solarized_light solarized_dark gruvbox_light gruvbox_dark amoled"
for image in ${themes}; do
  generate_rule ${image} "220 266 335 352 532" 16x ${QUALITY} ${THUMB_QUALITY_JPG} jpg >> Makefile
done
generate_rule phone "220 300 400 520 640 800 1000 1220" 16x ${QUALITY} ${THUMB_QUALITY_PNG} png >> Makefile
generate_rule tablet "545 640 720 800 880 960 1090 1635 2180" 16x16 ${QUALITY} ${THUMB_QUALITY_PNG} none >> Makefile
generate_rule notifications "363 474 590" 16x ${QUALITY} ${THUMB_QUALITY_JPG} jpg >> Makefile
generate_rule desktop "363 474 590 726 948 1180" 16x ${QUALITY} ${THUMB_QUALITY_JPG} jpg >> Makefile
generate_rule themes "363 474 590 726 948 1180" 16x ${QUALITY} ${THUMB_QUALITY_JPG} jpg >> Makefile