#!/bin/bash

cd $(dirname $(realpath -s ${0}))

function generate_thumb() {
  image=${1}
  default_resolution=${2}
  quality=${3}
  format=${4}

  case ${format} in
  "png")
    generate_thumb_png ${image} ${default_resolution} ${quality}
    ;;
  "jpg")
    generate_thumb_jpg ${image} ${default_resolution} ${quality}
    ;;
  "none")
    generate_thumb_none ${image} ${default_resolution} ${quality}
    ;;
  *)
    echo "Unknown format: $format"
    exit 1
    ;;
  esac
}

function generate_thumb_jpg() {
  image=${1}
  default_resolution=${2}
  quality=${3}

  convert ${image}.png -filter Lanczos -distort Resize 16x ${image}@thumb.png
  convert ${image}@thumb.png -filter Lanczos -distort Resize ${default_resolution} -quality ${quality} ${image}@thumb.jpg
  rm ${image}@thumb.png
}

function generate_thumb_png() {
  image=${1}
  default_resolution=${2}
  quality=${3}

  convert ${image}.png -filter Lanczos -distort Resize 16x ${image}@thumb.png
  convert ${image}@thumb.png -filter Lanczos -distort Resize ${default_resolution} ${image}@thumb.png
  pngquant --quality ${quality} ${image}@thumb.png
  mv ${image}@thumb-fs8.png ${image}@thumb.png
}

function generate_thumb_none() {
  image=${1}
  default_resolution=${2}
  quality=${3}

  convert -size ${default_resolution} xc:none ${image}@thumb.png
}